[llvm-commits] CVS: llvm/lib/Analysis/DataStructure/DataStructure.cpp

Misha Brukman brukman at cs.uiuc.edu
Tue May 20 13:46:02 PDT 2003


Changes in directory llvm/lib/Analysis/DataStructure:

DataStructure.cpp updated: 1.97 -> 1.98

---
Log message:

s/convertable/convertible/g


---
Diffs of the changes:

Index: llvm/lib/Analysis/DataStructure/DataStructure.cpp
diff -u llvm/lib/Analysis/DataStructure/DataStructure.cpp:1.97 llvm/lib/Analysis/DataStructure/DataStructure.cpp:1.98
--- llvm/lib/Analysis/DataStructure/DataStructure.cpp:1.97	Mon Mar  3 11:13:31 2003
+++ llvm/lib/Analysis/DataStructure/DataStructure.cpp	Tue May 20 13:45:31 2003
@@ -336,8 +336,8 @@
 
   // Check to see if we have a compatible, but different type...
   if (NewTySize == SubTypeSize) {
-    // Check to see if this type is obviously convertable... int -> uint f.e.
-    if (NewTy->isLosslesslyConvertableTo(SubType))
+    // Check to see if this type is obviously convertible... int -> uint f.e.
+    if (NewTy->isLosslesslyConvertibleTo(SubType))
       return false;
 
     // Check to see if we have a pointer & integer mismatch going on here,





More information about the llvm-commits mailing list